<? include ("barry.inc"); ?>

<? createHeader("Reporting a Bug"); ?>

<? createSubHeader("Information to Report"); ?>

<p>When reporting a bug, it is helpful to include as much information as you
can about your system, and the circumstances surrounding the bug.</p>

<p>
Information to include, if applicable:
<ul>
	<li>The exact error message you get, if any, when you encounter
		the problem</li>
	<li>Version of Barry</li>
	<li>How you installed Barry</li>
	<li>Any sample data that may help in reproducing the problem</li>
	<li>Name and version of your operating system</li>
	<li>Architecture of your system (32 bit? 64 bit? Intel? iMac?)</li>
</ul>
</p>

<p>Once you have all this information,
<?createLink("contact", "send it to us"); ?>.</p>

<p>If you also have a patch that solves the problem, see the page on
<? createLink("patches", "submitting patches"); ?>.</p>

